%   v1.0 # 09-jun-2020 
%
%   v2.0 # 04-oct-2020 
%
%   # SPCOMNAV-UAB #
%---------------------------------------------------------------------------------------------------- 
%-      Noise (SNR) analysis  
%
function    outt    =   SNR_Analysis(set,flg,out)

    
    
    %
    B       =   set.sig.B;
    T       =   set.sig.Tc;
    M       =   set.M;
    Mvis    =   set.Mvis;
    mu      =   set.sig.mu;
    Deltaf  =   5;      
    %
    Nsnr    =   set.estimation.Nsnr;
    CN0     =   set.estimation.CN0;
    R       =   set.estimation.R;
    %
    N       =   B*T;
    %
    fgen    =   0;
    initParams_NoiseAnalysis;
%     switch flg.Muser
%         case 0 
%             Ck      =   out.sig.Ck;    
%             ckp     =   out.sig.ckp;
%             ck_dc   =   out.dchirp.ck_dc;
%             ck_dcn  =   out.dchirp.ck_dcn;
%         case 1
%             Ck      =   out.MU.Cr;    
%             ckp     =   out.sig.Ck;
%             ck_dc   =   out.dchirp.ck_dc;
%             ck_dcn  =   out.dchirp.ck_dcn;
%             %
%             %   BOK-chirp power (put in genBOKchirp)
%             Psst         =   sum(ckp*ckp')/N;
%             Pss         =   repmat(Psst.',1,N);
%             %   Power normalization (all users)
%             Ckt         =   sqrt(1./(M*Pss)).*ckp;
% 
%             %
%         case 2
%             
%         case 3
%             
%     end
%     %
%     
% %     N       =   size(Ck,2);
%     
%     
%     %--     Noise parameters
%     k       =   1.38e-23;                   %   Boltzman cte
%     T0      =   290;                        %   Amb. temperature
%     N0      =   (k*T0);
%     Pn      =   (N0*B);                     %   (complex) Noise power (W)
%     %
%     CN0l    =   10.^(CN0/10);
%     Ps      =   (Pn/B)*(CN0l);
%     CN0t    =   10*log10((Ps.'*(Psst/(2)))/(N0));
    %-      Noise Performance (Estimation)
    %
    %--     CRLB computation
    
    %
    %---    Time-Delay (tau)
    if flg.ftau
        %
        tau         =   set.tau;
        CRLB        =   (6/(2*pi*T)^2)*(T./((B^2)*CN0l));
        %   Estimation parameters initialization
        %   (mu, var, bias, rmse)
        if( flg.Muser == 0 )
            mt      =   nan(2,Nsnr);
            vt      =   nan(2,Nsnr);
            bt      =   nan(2,Nsnr);
            et      =   nan(2,Nsnr);
        else
            mt      =   nan(1,Nsnr);
            vt      =   nan(1,Nsnr);
            bt      =   nan(1,Nsnr);
            et      =   nan(1,Nsnr);
        end
        %
        str         =   'Analyzing Time-Delay Estimation';
    end
    %
    %---    Freq. Doppler (fD) 
    % 
    if flg.fDopp
        %
        fD      =   set.fD;
        CRLBf   =   6./(CN0l*((2*pi*T)^2)*T);   % BOK CRLB with Ps = A^2
        %
        %   Estimation parameters initialization
        %   (mu, var, bias, rmse)
        if( flg.Muser == 0 )
            mf      =   nan(2,Nsnr);
            vf      =   nan(2,Nsnr);
            bf      =   nan(2,Nsnr);
            ef      =   nan(2,Nsnr);
        else
            mf      =   nan(1,Nsnr);
            vf      =   nan(1,Nsnr);
            bf      =   nan(1,Nsnr);
            ef      =   nan(1,Nsnr);
        end
            
        %
        if ~flg.ftau
            str     =   'Analyzing Freq. Doppler Estimation';
        else
            str     =   'Analyzing Time-Delay & Freq. Doppler Estimation';
        end
    end
    %
    %--     SNR Analysis
    disp([str ' with ' num2str(R)]); 
    disp('statistical realizations');
    disp('%%%%%%%%%%');
    for kk = 1:M
        %
        disp(['User #' num2str(kk)]);
        for ii = 1:Nsnr
            %
            disp(['Processing SNR #' num2str(ii) ' up to ' num2str(Nsnr) ' ...']);
            %
            if( CN0l(ii) == inf )
                Ps      =   1;
                Pn      =   0;
%             else
%                 Ps      =   (Pn/B)*(CN0l(ii));
            end
            %
            if flg.ftau
                tmpt    =   nan(2,R);
            end
            if flg.fDopp
                tmpf    =   nan(2,R);
            end
            %
            for jj = 1:R
                w           =   (sqrt(Pn/2))*(randn(1,N) + 1j*randn(1,N));
                if( flg.Muser == 0 )
                    ckpn        =   sqrt(Ps)*ckp(kk,:) + w;
                    %--  (Up/Down) de-chirp with noise (Powers given by SNR)
                    %-  Single-component (up or down) of a given satelite
                    %-  Do only if single-user analysis
                    %
                    spn_dc      =   ckpn.*ck_dc(kk,:);
                    [fdc,~]     =   FreqEstimation(spn_dc,spn_dc,B,M,Deltaf,flg.Muser);
                    ttp         =   mod(-fdc/mu(kk),T);
                    ffp         =   fdc;
                    %
                    Pck         =   (Ck*Ck')/N;
                    Ckn         =   sqrt(Ps/(4))*Ck + w;
                    sn_dc       =   Ckn.*ck_dc(kk,:);
                    sn_dcn      =   Ckn.*ck_dcn(kk,:);
                elseif( flg.Muser == 2 )
                    M           =   size(Ck,1);
                    N           =   size(dchirp.ck_dc1,2);
%                     Ncoh        =   N/Nnc;
                    Nfft        =   2^(nextpow2(N));
                    
                else
                    %   Power normalization
                    Pck         =   (Ck*Ck')/N;
%                     Ck          =   sqrt(2)*Ck;
                    Ck          =   sqrt(1/1)*Ck;
                    %
                    Ckn         =   sum(Ckt.*repmat(ck_dc(kk,:),M,1),1);
                    Cknn        =   sum(Ckt.*repmat(ck_dcn(kk,:),M,1),1);
%                     if( jj == 1 && ii == 1 )
%                         if( kk == 1 )
%                             figure;plot(abs(fftshift(fft(Ckn))));
%                             tmp_plot    =   Ckt.*repmat(ck_dc(kk,:),M,1);
%                         elseif( kk == M )
%                             plot(abs(fftshift(fft(tmp_plot(1,:)))),'--','linewidth',2);
%                             figure;plot(abs(fftshift(fft(tmp_plot(1,:)))));
%                         else
%                             hold on;plot(abs(fftshift(fft(Ckn))));
%                         end
%                     end
%                     temp        =   sqrt(Ps/2)*sum(Ckt(:,kk)) + w;
                    %
                    
                    %
                    %   Up/Down de-chirp with corresponding CN0
                    MUI         =   (Pck/(2*M))^(-1);
%                     A           =   sqrt(MUI*M*Ps/(Pck));
                    A           =   MUI^2*sqrt(Ps/(2));
                    sn_dc       =   (A*Ck + w) .* ck_dc(kk,:);
                    sn_dcn      =   (A*Ck + w) .* ck_dcn(kk,:);
                    %
%                     sn_dc          =   temp.*ck_dc(kk,:);
%                     sn_dcn         =   temp.*ck_dcn(kk,:);
                    %
                end
                %
                
                %
                [fdc,fdcn]          =   FreqEstimation(sn_dc,sn_dcn,B,1,Deltaf,flg.Muser);    
                [tt,ff]             =   getParamEstimation(fdc,fdcn,B,T,mu(kk),flg.Muser);
                %  
                if flg.ftau
                    if(flg.Muser == 0 )
                        tmpt(1,jj)      =   ttp;
                        tmpt(2,jj)      =   tt;
                    else
                        tmpt(1,jj)      =   tt;
                    end
                end
                if flg.fDopp
                    if(flg.Muser == 0 )
                        tmpf(1,jj)      =   ffp;
                        tmpf(2,jj)      =   ff;
                    else
                        tmpf(1,jj)      =   ff;
                    end
                end
            end
            %            
            if flg.ftau
                if(flg.Muser == 0 )
                    mt(:,ii)            =   nanmean(tmpt,2);
                    vt(:,ii)            =   nanvar(tmpt.');
                    bt(:,ii)            =   abs(tau - mt(:,ii));
                    et(:,ii)            =   vt(:,ii) + (bt(:,ii).^2);
                else
                    mt(ii)            =   nanmean(tmpt(1,:));
                    vt(ii)            =   nanvar(tmpt(1,:));
                    bt(ii)            =   abs(tau(kk) - mt(ii));
                    et(ii)            =   vt(ii) + (bt(ii).^2);
                end
            end
            %
            if flg.fDopp
                tmpf                =   wrap(tmpf,B);
                if(flg.Muser == 0 )
                    mf(:,ii)            =   nanmean(tmpf,2);
                    vf(:,ii)            =   nanvar(tmpf.');
                    bf(:,ii)            =   abs(fD - mf(:,ii));
                    ef(:,ii)            =   vf(:,ii) + (bf(:,ii).^2);
                else
                    mf(ii)            =   nanmean(tmpf(1,:));
                    vf(ii)            =   nanvar(tmpf(1,:));
                    bf(ii)            =   abs(fD(kk) - mf(ii));
                    ef(ii)            =   vf(ii) + (bf(ii).^2);
                end
            end
            % 
            
        end
        %
        %-      Save Results
        if flg.ftau
            outt.tau(kk).CRLB       =   CRLB;
            outt.tau(kk).m          =   mt;
            outt.tau(kk).v          =   vt;
            outt.tau(kk).b          =   bt;
            outt.tau(kk).e          =   et;
        end
        if flg.fDopp
            outt.fD(kk).CRLB        =   CRLBf;
            outt.fD(kk).m           =   mf;
            outt.fD(kk).v           =   vf;
            outt.fD(kk).b           =   bf;
            outt.fD(kk).e           =   ef;        
        end
%         outt.CN0                    =   CN0t;
    end
    
    
    
    
    
end