% function    [mu,f0]     =   initSigParams(B,Tc,M,flg)
%
%   Description:
%       Initialization of spceific CSS signal parameters. It includes the
%       CSS initial frequency and chirp rate.
%   
%   Inputs:
%       B   =   Signal bandwidth (Hz)
%       Tc  =   Chirp period (sec.)
%       M   =   Number of satellites in the constellation
%       flg =   Multi-Satellite flag to indicate the multi-satellite scheme
%               [0] for single satellite, [1] for multi-slope, [2] for
%               multi-dual slope, and [3] for multi-frequency
%
%---------------------------------------------------------------------------------------------------- 
%   @version    $2.0$
%   @date       $6-jul-2021$ $26-sep-2020$
%   @author     SPCOMNAV-UAB: Daniel Egea Roca (daniel.egea@uab.es) 
%---------------------------------------------------------------------------------------------------- 

function    [mu,f0]     =   initSigParams(B,Tc,M,flg)
%
    tmp                 =   B/Tc;                                           %   Fundamental chirp rate
    switch flg
            case 0  % Single-User
                mu      =   tmp;  
                f0      =   0;
            case 1  % Multi-Slope 1
                %
                mu      =   linspace(M*tmp,tmp,M).';  
                f0      =   zeros(length(mu),1); 
                %                           
            case 2  % Multi-Slope 2   
                %
                ki      =   (1 - (0:M-1)/M);                    
                mu1     =   ki*tmp;%2*ki*tmp;
                mu2     =   2*tmp - mu1;%2*(1-ki)*tmp;
                mu      =   [mu1.' mu2.'];
                f0      =   zeros(length(mu),1);
                %
            case 3  % Multi-Freq
                %
                Delta   =   B/(2*M);                 
                fmax    =   (B/2)-Delta;
                f0      =   linspace(-fmax,fmax,M);                 
                mu      =   tmp*ones(length(f0),1);  
                %
    end
end