%   initsetAndflg
%
%   Description:
%       Define sett and flg structures to initialize the desired
%       configuration
%
%   Inputs:
%       Configuration set in the setParams.m file
%
%   Outputs:
%
%       set    =   Structure with setting parameters (see setParams.m)
%
%       flg     =   Structure with flag options (see setParams.m)
%
%---------------------------------------------------------------------------------------------------- 
%   @version    $2.0$
%   @date       $8-jul-2021$ $9-jun-2020$
%   @author     SPCOMNAV-UAB: Daniel Egea Roca (daniel.egea@uab.es) 
%---------------------------------------------------------------------------------------------------- 
    %
    set.idsat       =   idsat;
    if( Muser ~= 0 )
        if( length(Mmax) > 1 || Nm == 1 )
            set.M       =   Mmax;    
        else
            set.M       =   ceil(linspace(2,Mmax,Nm));
        end 
        set.Mvis        =   ceil(Mvis);        
    end
    %
    if( length(Bmin) > 1 || NB == 1 )
        set.sig.B   =   Bmin;
        NB          =   length(Bmin);
    else
        set.sig.B   =   linspace(Bmin,Bmax,NB);
    end
    %  
    if( length(Tcmin) > 1 || NTc == 1)
        set.sig.Tc  =   Tcmin;
        NTc         =   length(Tcmin);
    else
        
        set.sig.Tc  =   linspace(Tcmin,Tcmax,NTc);       
    end
    %-  Round to 0.1 ms
    set.sig.Tc      =   round(set.sig.Tc*1e4)*1e-4;
    %
    if( length(CN0min) > 1 || Nc == 1 )
        CN0         =   CN0min;
        Nc          =   length(CN0min);
    else
        CN0         =   linspace(CN0min,CN0max,Nc);
    end
    %  
    if ftau
        set.tau                 =   tau;        
        set.estimation.Ntau     =   Ntau;
        set.estimation.Dtau     =   Dtau;
    end
    %
    if fDopp
        set.fD                  =   fD;
        set.estimation.NDopp    =   NDopp;
        set.estimation.Df       =   Df;            
    end 
    %
    if frmse       
        set.estimation.fsim     =   fsim;
        set.estimation.R        =   R;
        set.estimation.CN0      =   CN0;
        set.estimation.const    =   const;
%         set.estimation.acq      =   acq;
%         if acq
%             set.estimation.th   =   th;
%         end
        set.estimation.zpfact   =   zpfact;
    else
        set.estimation.CN0      =   inf;
        set.estimation.Nsnr     =   1;
        set.estimation.zpfact   =   0;
    end    
    %
    if fsens
        set.sens.R                  =   Rs;
        set.sens.Rd                 =   Rsd;        
        set.sens.opt                =   opt;
        set.sens.flg_nc             =   flg_nc;
        set.sens.fit                =   fit;
        set.sens.CN0                =   CN0;
        set.sens.Pfa                =   Pfa;
        %
        switch opt
            case 1
                set.sens.CN0min     =   CN0min;
                set.sens.CN0max     =   CN0max;
                set.sens.CN00       =   CN00;
            case 2
                set.sens.Tmin       =   Tmin;
                set.sens.Tmax       =   Tmax;
                set.sens.T0         =   T0;            
        end
        %        
        
    else
        set.samp.Nc                 =   1;

    end  
    %-
    %-  Save flg structure
    %
    flg.Muser               =   Muser;
    flg.save                =   save;
    flg.graphics            =   graphics;
    flg.ftau                =   ftau;
    flg.fDopp               =   fDopp;
    flg.frmse               =   frmse;
    flg.fsens               =   fsens;
    flg.fMUI                =   fMUI;
    flg.fcomplex            =   fcomplex;
    %
    if ~graphics
        %
        plot.fsig           =   0;
        plot.fdchirp        =   0;
        plot.fest           =   0;
        plot.fmui           =   0;
        plot.frmse          =   0;
        plot.fsens          =   0;
        plot.fcomplex       =   0;
        %
    else
        if( (ftau && fDopp) == 0 )
            plot.fest       =   0;
        end
        if ~fMUI
            plot.fmui       =   0;
        end
        if ~frmse
            plot.frmse      =   0;
        end
        if ~fsens
            plot.fsens      =   0;
        end
        if ~fcomplex
            plot.fcomplex   =   0;
        end
    end
    flg.plot            =   plot;
    %
    %-
    set.samp.Nsb                =   Nsb; 
    set.samp.NB                 =   NB;
    set.samp.NTc                =   NTc;
    set.samp.Nc                 =   Nc;
    set.samp.Nnc                =   Nnc;
    %