%   v1.0 # 19-apr-2020 
%
%   v1.1 # 9-may-2020 
%
%   # SPCOMNAV-UAB #
%---------------------------------------------------------------------------------------------------- 
%-      Plot Spectrum of de-chirped signal
%
%
%   flg: Multi-User flag
%
function    plotResults_dchirpSpect(out,set,flg)
%
    %-  Init. params.
    %
    B           =   set.sig.B;                                              %   Get signal bandwidth
    Fsamp       =   set.Fs;                                                 %   Get sampling rate
    N           =   set.samp.Ns*set.samp.Nsb;                               %   Get number of samples
    %
    Nfft        =   2^(nextpow2(N)+2);                                      %   Number of samples to perform FFT
    f0          =   (Fsamp/2)*linspace(-1,1,Nfft);                          %   Frequency axys for the FFT
    %
    %-  Single Satellite
    %
    if( flg == 0 )
        s_dc        =   out.dchirp.s_dc;
        sd_dc       =   out.dchirp.s_dcn;
        ss_dc       =   out.dchirp.ss_dc;
        ssd_dc      =   out.dchirp.ss_dcn;
    %
    %-
    %-  Multi-DualSlope scheme
    %
    elseif( flg == 2 )
        %-  First slope
        %
        s_dc1       =   out.dchirp.s_dc1(1,:);                               % 1st (single) user (up-chirp) de-chirp 
        r_dc1       =   out.MU.r_dc1(1,:);                                   % 1st (multi-) user (up-chirp) de-chirp
        s_dcn1      =   out.dchirp.s_dcn1(1,:);                              % 1st (single) user (down-chirp) de-chirp 
        r_dcn1      =   out.MU.r_dcn1(1,:);                                  % 1st (multi-) user (down-chirp) de-chirp
        %
        %-
        %- 2nd slope
        %
        s_dc2       =   out.dchirp.s_dc2(1,:);                               % 1st (single) user (up-chirp) de-chirp 
        r_dc2       =   out.MU.r_dc2(1,:);                                   % 1st (multi-) user (up-chirp) de-chirp
        s_dcn2      =   out.dchirp.s_dcn2(1,:);                              % 1st (single) user (down-chirp) de-chirp 
        r_dcn2      =   out.MU.r_dcn2(1,:);                                  % 1st (multi-) user (down-chirp) de-chirp
        %
        %-
    %
    %-
    %-  Multi-Slope & Multi-Freq. scheme
    %
    else      
        s_dc        =   out.dchirp.s_dc(1,:);                               % 1st (single) user (up-chirp) de-chirp 
        r_dc        =   out.MU.r_dc(1,:);                                   % 1st (multi-) user (up-chirp) de-chirp
        s_dcn       =   out.dchirp.s_dcn(1,:);                              % 1st (single) user (down-chirp) de-chirp 
        r_dcn       =   out.MU.r_dcn(1,:);                                  % 1st (multi-) user (down-chirp) de-chirp
    end
    % 
    %-  Compute FFT
    %
    switch flg
        case 0
            SS_dc       =   abs(fftshift(fft(ss_dc,Nfft))).^2;
            SSd_dc      =   abs(fftshift(fft(ssd_dc,Nfft))).^2;
            S_dc        =   abs(fftshift(fft(s_dc,Nfft))).^2;
            Sd_dc       =   abs(fftshift(fft(sd_dc,Nfft))).^2;
        case 2
            S_dc        =   abs(fftshift(fft(s_dc1,Nfft))).^2;
            S_dcn       =   abs(fftshift(fft(s_dcn1,Nfft))).^2;
            R_dc        =   abs(fftshift(fft(r_dc1,Nfft))).^2;            
            R_dcn       =   abs(fftshift(fft(r_dcn1,Nfft))).^2;
            %
            S_dc2       =   abs(fftshift(fft(s_dc2,Nfft))).^2;
            S_dcn2      =   abs(fftshift(fft(s_dcn2,Nfft))).^2;
            R_dc2       =   abs(fftshift(fft(r_dc2,Nfft))).^2;            
            R_dcn2      =   abs(fftshift(fft(r_dcn2,Nfft))).^2;
            
        otherwise
            S_dc        =   abs(fftshift(fft(s_dc,Nfft))).^2;
            S_dcn       =   abs(fftshift(fft(s_dcn,Nfft))).^2;
            R_dc        =   abs(fftshift(fft(r_dc,Nfft))).^2;            
            R_dcn       =   abs(fftshift(fft(r_dcn,Nfft))).^2;
    end
    %
    %-
    %-  Plot results
    %
    if( flg == 0 )  % Single-satellite
        figure;plot(f0,SS_dc,'LineWidth',2);
        xlabel('Frequency (Hz)');
        ylabel('Power Spectral Density');
        xlim([-B B]);
        title('De-Chirped Up-Chirp component');
        grid
        %
        figure;plot(f0,SSd_dc,'LineWidth',2);
        xlabel('Frequency (Hz)');
        ylabel('Power Spectral Density');
        xlim([-B B]);
        title('De-Chirped Down-Chirp component');
        grid
        % 
        figure;subplot(2,1,1);
        plot(f0,S_dc);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite (up-chirp) de-chirp');
        grid;
        subplot(2,1,2);plot(f0,Sd_dc);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite (down-chirp) de-chirp');
        grid;
    elseif( flg == 2)
        figure;subplot(2,1,1);
        plot(f0,S_dc,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Single-User (up-chirp) de-chirp; 1st slope');
        legend
        grid;
        subplot(2,1,2);plot(f0,R_dc,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Multi-User (up-chirp) de-chirp; 1st slope');
        legend
        grid;
        %
        figure;subplot(2,1,1);
        plot(f0,S_dcn,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Single-User (down-chirp) de-chirp; 1st slope');
        legend
        grid;
        subplot(2,1,2);plot(f0,R_dcn,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Multi-User (down-chirp) de-chirp; 1st slope');
        legend
        grid;
        xlim([-B B]);
        %
        plot(f0,S_dc2,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Single-User (up-chirp) de-chirp; 2nd slope');
        legend
        grid;
        subplot(2,1,2);plot(f0,R_dc2,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Multi-User (up-chirp) de-chirp; 2nd slope');
        legend
        grid;
        %
        figure;subplot(2,1,1);
        plot(f0,S_dcn2,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Single-User (down-chirp) de-chirp; 2nd slope');
        legend
        grid;
        subplot(2,1,2);plot(f0,R_dcn2,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Multi-User (down-chirp) de-chirp; 2nd slope');
        legend
        grid;
        xlim([-B B]);
    else
        figure;subplot(2,1,1);
        plot(f0,S_dc,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Single-User (up-chirp) de-chirp');
        legend
        grid;
        subplot(2,1,2);plot(f0,R_dc,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Multi-User (up-chirp) de-chirp');
        legend
        grid;
        %
        figure;subplot(2,1,1);
        plot(f0,S_dcn,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Single-User (down-chirp) de-chirp');
        legend
        grid;
        subplot(2,1,2);plot(f0,R_dcn,'LineWidth',2);xlabel('Frequency (Hz)');
        xlim([-B B]);title('Composite Multi-User (down-chirp) de-chirp');
        legend
        grid;
        xlim([-B B]);
    end
    %
    
    %  
    
    %
end